@@ -161,6 +161,15 @@ url_callback_handler(const gchar *interface, const gchar *method, GArray *argume
 	return OSSO_OK;
 }
 
+static void
+clear_sync_settings()
+{
+	settings_save_last_sync_revision(0);
+	settings_save_last_sync_time(0);
+	settings_save_sync_base_url("");
+	settings_save_oauth_access_token("");
+	settings_save_oauth_access_secret("");
+}
 
 static void
 on_sync_auth_but_clicked(GtkButton *button, SettingsWidget *widget)
@@ -174,22 +183,35 @@ on_sync_auth_but_clicked(GtkButton *button, SettingsWidget *widget)
 
 	GtkWindow *parent = GTK_WINDOW(widget->window);
 
-	if (url == NULL) {
+	if (url == NULL || strcmp(url, "") == 0) {
 		return;
 	}
 
 	gchar *old_url = settings_load_sync_base_url();
 
-	if (old_url != NULL && strcmp(old_url, "") != 0 && strcmp(url, old_url) != 0) {
-		GtkWidget *dialog = ui_helper_create_yes_no_dialog(parent, "Really reset the sync settings?");
+	if (old_url != NULL && strcmp(old_url, "") != 0) {
+
+		gchar *msg;
+
+		if (strcmp(url, old_url) == 0) {
+			msg = g_strconcat("You are already authenticated with\n'", old_url, "'. Are you sure you want to reset the synchonization settings?", NULL);
+		} else {
+			msg = g_strconcat("You are currently authenticated with\n'", old_url, "'. Are you sure you want to reset the synchonization settings?", NULL);
+		}
+
+		GtkWidget *dialog = ui_helper_create_yes_no_dialog(parent, msg);
 		int ret = gtk_dialog_run(GTK_DIALOG(dialog));
 		gtk_widget_destroy(dialog);
+		g_free(msg);
 		if (ret == GTK_RESPONSE_YES) {
-			/* Reset settings */
-			settings_save_last_sync_revision(0);
-			settings_save_last_sync_time(0);
-			settings_save_sync_base_url("");
+			clear_sync_settings();
 		} else {
+			gtk_widget_set_sensitive(button, FALSE);
+			#ifdef HILDON_HAS_APP_MENU
+			hildon_entry_set_text(HILDON_ENTRY(widget->url_entry), old_url);
+			#else
+			gtk_entry_set_text(GTK_ENTRY(widget->url_entry), old_url);
+			#endif
 			return;
 		}
 	}
@@ -228,7 +250,7 @@ on_sync_auth_but_clicked(GtkButton *button, SettingsWidget *widget)
 	}
 
 	/* If successfull, save url */
-	settings_save_sync_base_url(url);
+	/*settings_save_sync_base_url(url);*/
 
 	/* Open link in browser */
 	AppData *app_data = app_data_get();
@@ -239,7 +261,7 @@ on_sync_auth_but_clicked(GtkButton *button, SettingsWidget *widget)
 	g_printerr("Opening browser with URL: >%s<\n", link);
 
 
-	GtkWidget *dialog = ui_helper_create_cancel_dialog(parent, "Please grant access on the website, which just opened.");
+	GtkWidget *dialog = ui_helper_create_cancel_dialog(parent, "Please grant access on the website of your service provider which was just opened.\nAfter that you will be automatically redirected to back Conboy.");
 
 
 	struct DialogData data;
@@ -264,19 +286,19 @@ on_sync_auth_but_clicked(GtkButton *button, SettingsWidget *widget)
 		if (conboy_get_access_token(api->access_token_url, data.verifier)) {
 
 			gtk_widget_set_sensitive(GTK_WIDGET(button), FALSE);
-			ui_helper_show_confirmation_dialog(parent, "You're authenticated. Everything is good :)", FALSE);
-
+			ui_helper_show_confirmation_dialog(parent, "<b>You are successfully authenticated</b>\nYou can now use the synchronization from the main menu.", FALSE);
+			settings_save_sync_base_url(url);
 		} else {
-			ui_helper_show_confirmation_dialog(parent, "Could not get the access token. Not good :(", FALSE);
+			ui_helper_show_confirmation_dialog(parent, "Conboy could not get an access token from your service provider. Please try again.", FALSE);
 			settings_save_sync_base_url("");
 		}
-	} else if (result == GTK_RESPONSE_CLOSE) {
-		ui_helper_show_confirmation_dialog(parent, "You have canceled the authentication process.", FALSE);
+	} else if (result == 666) {
+		ui_helper_show_confirmation_dialog(parent, "You have manually canceled the authentication process.", FALSE);
 	} else if (result == GTK_RESPONSE_REJECT) {
-		ui_helper_show_confirmation_dialog(parent, "Problems with the OAuth verifier. Not good :(", FALSE);
+		ui_helper_show_confirmation_dialog(parent, "There were problems with the data received from your service provider. Please try again.", FALSE);
 		settings_save_sync_base_url("");
 	} else {
-		ui_helper_show_confirmation_dialog(parent, "Unknown error. Not good :(", FALSE);
+		ui_helper_show_confirmation_dialog(parent, "An unknown error occured, please try again.", FALSE);
 	}
 
 }
